==> camunda-operate-client-java-8.1.7.2-sources.jar: io/camunda/operate/dto/ProcessInstance.java <==
package io.camunda.operate.dto;

import java.util.Date;

public class ProcessInstance {
    private Long key;
    private Long processVersion;
    private String bpmnProcessId;
    private Long parentKey;
    private Date startDate;
    private Date endDate;
    private ProcessInstanceState state;
    private Long processDefinitionKey;

    public Long getKey() {
        return key;
    }

    public void setKey(Long key) {
        this.key = key;
    }

    public Long getProcessVersion() {
        return processVersion;
    }

    public void setProcessVersion(Long processVersion) {
        this.processVersion = processVersion;
    }

    public String getBpmnProcessId() {
        return bpmnProcessId;
    }

    public void setBpmnProcessId(String bpmnProcessId) {
        this.bpmnProcessId = bpmnProcessId;
    }

    public Long getParentKey() {
        return parentKey;
    }

    public void setParentKey(Long parentKey) {
        this.parentKey = parentKey;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public ProcessInstanceState getState() {
        return state;
    }

    public void setState(ProcessInstanceState state) {
        this.state = state;
    }

    public Long getProcessDefinitionKey() {
        return processDefinitionKey;
    }

    public void setProcessDefinitionKey(Long processDefinitionKey) {
        this.processDefinitionKey = processDefinitionKey;
    }
}

==> camunda-operate-client-java-8.3.0-sources.jar: io/camunda/operate/dto/ProcessInstance.java <==
package io.camunda.operate.dto;

import java.util.Date;

public class ProcessInstance {
    private Long key;
    private Long processVersion;
    private String bpmnProcessId;
    private Long parentKey;
    private Date startDate;
    private Date endDate;
    private ProcessInstanceState state;
    private Long processDefinitionKey;
    private String tenantId;

    public Long getKey() {
        return key;
    }

    public void setKey(Long key) {
        this.key = key;
    }

    public Long getProcessVersion() {
        return processVersion;
    }

    public void setProcessVersion(Long processVersion) {
        this.processVersion = processVersion;
    }

    public String getBpmnProcessId() {
        return bpmnProcessId;
    }

    public void setBpmnProcessId(String bpmnProcessId) {
        this.bpmnProcessId = bpmnProcessId;
    }

    public Long getParentKey() {
        return parentKey;
    }

    public void setParentKey(Long parentKey) {
        this.parentKey = parentKey;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public ProcessInstanceState getState() {
        return state;
    }

    public void setState(ProcessInstanceState state) {
        this.state = state;
    }

    public Long getProcessDefinitionKey() {
        return processDefinitionKey;
    }

    public void setProcessDefinitionKey(Long processDefinitionKey) {
        this.processDefinitionKey = processDefinitionKey;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }
}
